summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
authorBill Wendling <wendling@ncsa.uiuc.edu>2001-03-08 20:17:12 (GMT)
committerBill Wendling <wendling@ncsa.uiuc.edu>2001-03-08 20:17:12 (GMT)
commita4cd98c011f5a6e5f78e15664de49d31f5213e56 (patch)
tree233fa1a940383631829262adca09bbf0d7dbb82a /tools
parent8910ca14c4b4fffb04eea6ddf1001156e0a0fa61 (diff)
downloadhdf5-a4cd98c011f5a6e5f78e15664de49d31f5213e56.zip
hdf5-a4cd98c011f5a6e5f78e15664de49d31f5213e56.tar.gz
hdf5-a4cd98c011f5a6e5f78e15664de49d31f5213e56.tar.bz2
[svn-r3569] Purpose:
Update Description: Changed name of h5tools functions. Solution: Changed h5dump_fixtype() -> h5tools_fixtype() Platforms tested: Linux
Diffstat (limited to 'tools')
-rw-r--r--tools/lib/talign.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/tools/lib/talign.c b/tools/lib/talign.c
index 7bf0659..5c4f88d 100644
--- a/tools/lib/talign.c
+++ b/tools/lib/talign.c
@@ -1,12 +1,13 @@
/*
* Small program to illustrate the "misalignment" of members within a compound
* datatype, in a datatype fixed by h5dump_fixtype().
*/
#include <string.h>
#include <stdlib.h>
#include <unistd.h> /* Required for unlink() */
#include "hdf5.h"
+#include "h5tools.h"
const char *fname = "talign.h5";
const char *setname = "align";
@@ -18,8 +19,6 @@ const char *setname = "align";
* another per construction)
*/
-extern hid_t h5dump_fixtype(hid_t);
-
int main(void)
{
hid_t fil,spc,set;
@@ -73,7 +72,7 @@ int main(void)
H5Tinsert(cmp, "Not Ok", sizeof(fok) + sizeof(string5), array_dt);
H5Tclose(array_dt);
- fix = h5dump_fixtype(cmp);
+ fix = h5tools_fixtype(cmp);
cmp1 = H5Tcreate(H5T_COMPOUND, sizeof(fok));
@@ -1,12 +1,13 @@
/*
* Small program to illustrate the "misalignment" of members within a compound
- * datatype, in a datatype fixed by h5dump_fixtype().
+ * datatype, in a datatype fixed by h5tools_fixtype().
*/
#include <string.h>